
coordio's documentation
=============================================

This is the documentation for the SDSS Python product coordio. The current version is |coordio_version|. You can install the package by doing

.. code-block:: console

  $ pip install sdss-coordio


Contents
--------

.. toctree::
  :maxdepth: 2

  What's new in coordio? <CHANGELOG>
  Introduction to coordio <intro>


Reference
---------

.. toctree::
   :maxdepth: 1

   api


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
